@@ -1,7 +1,7 @@
 """Package that automatically caches and dispatch serialization and deserialization to the correct functions depending on the extension."""
-from .cache import Cache
+from .cache import Cache, cache
 
 import logging
 logging.getLogger(__name__).addHandler(logging.NullHandler())
 
-__all__ = ["Cache"]
\ No newline at end of file
+__all__ = ["Cache", "cache"]
\ No newline at end of file
